@@ -18,18 +18,13 @@ class PayerConfig(AppConfig):
     gql_mutation_payer_update_perms = []
     gql_mutation_payer_delete_perms = []
 
-    def _configure_permissions(self, cfg):
-        PayerConfig.gql_query_payers_perms = cfg["gql_query_payers_perms"]
-        PayerConfig.gql_mutation_payer_add_perms = cfg["gql_mutation_payer_add_perms"]
-        PayerConfig.gql_mutation_payer_update_perms = cfg[
-            "gql_mutation_payer_update_perms"
-        ]
-        PayerConfig.gql_mutation_payer_delete_perms = cfg[
-            "gql_mutation_payer_delete_perms"
-        ]
+    def __load_config(self, cfg):
+        for field in cfg:
+            if hasattr(PayerConfig, field):
+                setattr(PayerConfig, field, cfg[field])
 
     def ready(self):
         from core.models import ModuleConfiguration
 
         cfg = ModuleConfiguration.get_or_default(MODULE_NAME, DEFAULT_CFG)
-        self._configure_permissions(cfg)
+        self.__load_config(cfg)
