@@ -7,8 +7,10 @@ from django.utils.translation import gettext as _, gettext_lazy
 from payer.apps import PayerConfig
 from core.schema import OrderedDjangoFilterConnectionField
 from .models import Payer
+from location.models import Location, LocationManager
+from product.schema import ProductGQLType
 
-from .gql_queries import PayerGQLType
+from .gql_queries import PayerGQLType, FundingGQLType
 
 from .gql_mutations import (
     CreatePayerMutation,
@@ -19,6 +21,18 @@ from .gql_mutations import (
 
 
 class Query(graphene.ObjectType):
+    fundings = OrderedDjangoFilterConnectionField(
+        FundingGQLType,
+        payer_id=graphene.ID(),
+        client_mutation_id=graphene.String(),
+        show_history=graphene.Boolean(),
+        parent_location_level=graphene.Int(),
+        orderBy=graphene.List(of_type=graphene.String),
+    )
+    
+    funding = graphene.Field(FundingGQLType, uuid=graphene.UUID())
+
+        
     payers = OrderedDjangoFilterConnectionField(
         PayerGQLType,
         show_history=graphene.Boolean(),
@@ -38,20 +52,23 @@ class Query(graphene.ObjectType):
     def resolve_payers(self, info, **kwargs):
         if not info.context.user.has_perms(PayerConfig.gql_query_payers_perms):
             raise PermissionDenied(_("unauthorized"))
-        filters = []
+
+        filters = Payer.objects
         show_history = kwargs.get("show_history", False)
         if not show_history:
-            filters += filter_validity(**kwargs)
+            filters = filters.filter(*filter_validity(**kwargs))
 
         search = kwargs.get("search", None)
         if search is not None:
-            filters.append(
+            filters = filters.filter(
                 Q(name__icontains=search)
                 | Q(phone__icontains=search)
                 | Q(email__icontains=search)
             )
 
-        return gql_optimizer.query(Payer.objects.filter(*filters), info)
+        filters = LocationManager().build_user_location_filter_query(info.context.user._u, queryset = filters)
+
+        return gql_optimizer.query(filters, info)
 
 
 class Mutation(graphene.ObjectType):
